Event

Struct Event 

pub struct Event {
    pub id: i64,
    pub name: String,
    pub description: Option<String>,
    pub start_date: Option<String>,
    pub end_date: Option<String>,
    pub location: Option<String>,
    pub event_type: Option<String>,
    pub rsvp: bool,
    pub slips_required: bool,
    pub invited_users: Vec<InvitedUser>,
    pub units: Vec<EventUnit>,
}

Fields

id: i64name: Stringdescription: Option<String>start_date: Option<String>end_date: Option<String>location: Option<String>event_type: Option<String>rsvp: boolslips_required: boolinvited_users: Vec<InvitedUser>units: Vec<EventUnit>

Implementations

Source

impl Event

pub fn event_id(&self) -> i64

For compatibility with code that expects event_id

pub fn unit_id(&self) -> Option<i64>

Get the unit ID from the first unit in the units array

pub fn formatted_date(&self) -> String

pub fn formatted_time(&self) -> Option<String>

pub fn formatted_datetime_short(&self) -> String

Compact date/time for list view: “Jan 26 5:00p”

pub fn formatted_datetime_standard(&self) -> String

Standard date/time format: “MM/DD/YYYY HH:mm”

pub fn formatted_start_datetime(&self) -> String

Formatted start datetime: “Feb 06, 2026 @ 07:00 PM”

pub fn formatted_end_datetime(&self) -> String

Formatted end datetime: “Feb 08, 2026 @ 10:00 AM”

pub fn event_type_short(&self) -> &str

Short event type for list view

pub fn derived_type(&self) -> &str

Derive a meaningful event type from available fields The API eventType is often just “Other”, so we infer from other fields

pub fn going_count(&self) -> i32

pub fn not_going_count(&self) -> i32

pub fn no_response_count(&self) -> i32

pub fn adult_rsvp_counts(&self) -> (i32, i32)

Adult RSVP counts: (going, not_going)

pub fn scout_rsvp_counts(&self) -> (i32, i32)

Scout RSVP counts: (going, not_going)

Check if this event matches a search query (case-insensitive). Query should already be lowercased.

pub fn respondents(&self) -> (Vec<&InvitedUser>, Vec<&InvitedUser>)

Invited users who have responded (Going or Not Going), split by adult/youth.

pub fn rsvp_summary(&self) -> String

pub fn cmp_by_column(a: &Event, b: &Event, column: EventSortColumn) -> Ordering

Compare two events by the given column, with name as tiebreaker.